@@ -1,8 +1,8 @@
-from robocode_ls_core.workspace import Workspace, Document
-from robocode_ls_core.basic import overrides
-from robocode_ls_core.cache import instance_cache
+from robocorp_ls_core.workspace import Workspace, Document
+from robocorp_ls_core.basic import overrides
+from robocorp_ls_core.cache import instance_cache
 from robotframework_ls.constants import NULL
-from robocode_ls_core.robotframework_log import get_logger
+from robocorp_ls_core.robotframework_log import get_logger
 
 log = get_logger(__name__)
 
@@ -90,3 +90,17 @@ class RobotDocument(Document):
         else:
             log.critical("Unrecognized section: %s", t)
             return get_model(source)
+
+    def find_line_with_contents(self, contents: str) -> int:
+        """
+        :param contents:
+            The contents to be found.
+            
+        :return:
+            The 0-based index of the contents.
+        """
+        for i, line in enumerate(self.iter_lines()):
+            if contents in line:
+                return i
+        else:
+            raise AssertionError(f"Did not find >>{contents}<< in doc.")
