@@ -1,6 +1,8 @@
-from robocode_ls_core.python_ls import PythonLanguageServer
-from robocode_ls_core.basic import overrides
-from robocode_ls_core.robotframework_log import get_logger
+from robocorp_ls_core.python_ls import PythonLanguageServer
+from robocorp_ls_core.basic import overrides
+from robocorp_ls_core.robotframework_log import get_logger
+from typing import Optional
+from robocorp_ls_core.protocols import IConfig
 
 
 log = get_logger(__name__)
@@ -23,11 +25,17 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         PythonLanguageServer.__init__(self, read_from, write_to, max_workers=1)
         self._version = None
 
+    @overrides(PythonLanguageServer._create_config)
+    def _create_config(self) -> IConfig:
+        from robotframework_ls.robot_config import RobotConfig
+
+        return RobotConfig()
+
     def m_version(self):
         if self._version is not None:
             return self._version
         try:
-            import robot  # @UnusedImport
+            import robot  # noqa
         except:
             log.exception("Unable to import 'robot'.")
             version = "NO_ROBOT"
@@ -43,24 +51,15 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         return self._version
 
     def _check_min_version(self, min_version):
-        from robocode_ls_core.basic import check_min_version
+        from robocorp_ls_core.basic import check_min_version
 
         version = self.m_version()
         return check_min_version(version, min_version)
 
-    @property
-    def config(self):
-        return self._config
-
-    @config.setter
-    def config(self, config):
-        self._config = config
-        self.libspec_manager.config = config
-
     @overrides(PythonLanguageServer.m_workspace__did_change_configuration)
     def m_workspace__did_change_configuration(self, **kwargs):
         PythonLanguageServer.m_workspace__did_change_configuration(self, **kwargs)
-        self.config = self.config  # i.e.: trigger update of settings where needed.
+        self.libspec_manager.config = self.config
 
     @overrides(PythonLanguageServer.lint)
     def lint(self, *args, **kwargs):
@@ -76,7 +75,7 @@ class RobotFrameworkServerApi(PythonLanguageServer):
 
     def m_lint(self, doc_uri):
         if not self._check_min_version((3, 2)):
-            from robocode_ls_core.lsp import Error
+            from robocorp_ls_core.lsp import Error
 
             msg = (
                 "robotframework version (%s) too old for linting.\n"
@@ -135,11 +134,11 @@ class RobotFrameworkServerApi(PythonLanguageServer):
             return []
         return keyword_completions.complete(completion_context)
 
-    def m_find_definition(self, doc_uri, line, col):
+    def m_find_definition(self, doc_uri, line, col) -> Optional[list]:
         from robotframework_ls.impl.find_definition import find_definition
         import os.path
-        from robocode_ls_core.lsp import Location, Range
-        from robocode_ls_core import uris
+        from robocorp_ls_core.lsp import Location, Range
+        from robocorp_ls_core import uris
 
         completion_context = self._create_completion_context(doc_uri, line, col)
         if completion_context is None:
@@ -179,7 +178,7 @@ class RobotFrameworkServerApi(PythonLanguageServer):
     def m_code_format(self, text_document, options):
         from robotframework_ls.impl.formatting import robot_source_format
         from robotframework_ls.impl.formatting import create_text_edit_from_diff
-        from robocode_ls_core.lsp import TextDocumentItem
+        from robocorp_ls_core.lsp import TextDocumentItem
 
         text_document_item = TextDocumentItem(**text_document)
         text = text_document_item.text
@@ -223,11 +222,9 @@ class RobotFrameworkServerApi(PythonLanguageServer):
         )
 
     def m_shutdown(self, **_kwargs):
-        ret = PythonLanguageServer.m_shutdown(self, **_kwargs)
+        PythonLanguageServer.m_shutdown(self, **_kwargs)
         self.libspec_manager.dispose()
-        return ret
 
     def m_exit(self, **_kwargs):
-        ret = PythonLanguageServer.m_exit(self, **_kwargs)
+        PythonLanguageServer.m_exit(self, **_kwargs)
         self.libspec_manager.dispose()
-        return ret
